https://github.com/amosjyng/langchain-visualizer/blob/main/tests/demo.ipynb


# 研究结构化输出
# 研究 agents

1w字以内整篇理解


# 知识库应用 https://zhuanlan.zhihu.com/p/637733426


https://github.com/BerriAI/litellm

https://github.com/jmorganca/ollama


https://github.com/chatchat-space/Langchain-Chatchat/blob/master/document_loaders/myimgloader.py

https://github.com/chatchat-space/Langchain-Chatchat/blob/master/document_loaders/mypdfloader.py
